@@ -45,7 +45,7 @@
 #include <cerrno>
 #include <cstring>
 
-// For ntohl & Co.
+// For htonl & Co.
 #ifdef WIN32
 #   include <winsock2.h>
 #else
@@ -63,6 +63,9 @@
 #else
 #   define _(String) String
 #endif
+#ifdef WIN32
+#   include <windows.h>
+#endif
 
 #include "hashtable.h"
 #include "encoding.h"
@@ -124,6 +127,10 @@ void readLetters(const char *iFileName, DictHeaderInfo &ioHeaderInfo)
     string line;
     while (getline(in, line))
     {
+        // Ignore empty lines
+        if (line == "" || line == "\r" || line == "\n")
+            continue;
+
         // Split the lines on space characters
         vector<string> tokens;
         boost::char_separator<char> sep(" ");
@@ -134,17 +141,13 @@ void readLetters(const char *iFileName, DictHeaderInfo &ioHeaderInfo)
             tokens.push_back(*it);
         }
 
-        // Ignore empty lines
-        if (tokens.empty())
-            continue;
-
         // We expect 5 fields on the line, and the first one is a letter, so
         // it cannot exceed 4 bytes
         if (tokens.size() != 5 || tokens[0].size() > 4)
         {
             ostringstream ss;
             ss << "readLetters: Invalid line in " << iFileName;
-            ss << " (line " << lineNb;
+            ss << " (line " << lineNb << ")";
             throw DicException(ss.str());
         }
 
@@ -156,9 +159,21 @@ void readLetters(const char *iFileName, DictHeaderInfo &ioHeaderInfo)
 
         if (letter.size() != 1)
         {
-            ostringstream ss;
-            ss << "readLetters: Invalid letter at line " << lineNb;
-            throw DicException(ss.str());
+            // On the first line, there could be the BOM...
+            if (lineNb == 1 && tokens[0].size() > 3 &&
+                (uint8_t)tokens[0][0] == 0xEF &&
+                (uint8_t)tokens[0][1] == 0xBB &&
+                (uint8_t)tokens[0][2] == 0xBF)
+            {
+                // BOM detected, remove the first char in the wide string
+                letter.erase(0, 1);
+            }
+            else
+            {
+                ostringstream ss;
+                ss << "readLetters: Invalid letter at line " << lineNb;
+                throw DicException(ss.str());
+            }
         }
 #undef MAX_SIZE
 
@@ -394,6 +409,7 @@ void printUsage(const string &iBinaryName)
          << _("  -d, --dicname <string>  Set the dictionary name and version") << endl
          << _("  -l, --letters <string>  Path to the file containing the letters (see below)") << endl
          << _("  -i, --input <string>    Path to the uncompressed dictionary file (encoded in UTF-8)") << endl
+         << _("                          The words must be in alphabetical order, without duplicates") << endl
          << _("  -o, --output <string    Path to the generated compressed dictionary file") << endl
          << _("Other options:") << endl
          << _("  -h, --help              Print this help and exit") << endl
@@ -425,7 +441,18 @@ int main(int argc, char* argv[])
 
 #if ENABLE_NLS
     // Set the message domain
-    bindtextdomain(PACKAGE, LOCALEDIR);
+#ifdef WIN32
+    // Get the absolute path, as returned by GetFullPathName()
+    char baseDir[MAX_PATH];
+    GetFullPathName(argv[0], MAX_PATH, baseDir, NULL);
+    char *pos = strrchr(baseDir, L'\\');
+    if (pos)
+        *pos = '\0';
+    const string localeDir = baseDir + string("\\locale");
+#else
+    static const string localeDir = LOCALEDIR;
+#endif
+    bindtextdomain(PACKAGE, localeDir.c_str());
     textdomain(PACKAGE);
 #endif
 
