@@ -100,10 +100,10 @@ public:
 
     /**
      * Returns the character code associated with an element,
-     * codes may range from 0 to 31. 0 is the null character.
+     * codes may range from 0 to 63. 0 is the null character.
      * @returns code for the encoded character
      */
-    const dic_code_t getCode(const dic_elt_t &elt) const;
+    dic_code_t getCode(const dic_elt_t &elt) const;
 
     /**
      * Returns the wide character associated with an element.
@@ -114,14 +114,14 @@ public:
     /**
      * Returns a boolean to show if there is another available
      * character in the current depth (a neighbor in the tree)
-     * @returns 0 or 1 (true)
+     * @return true if the character is the last one at the current depth
      */
     bool isLast(const dic_elt_t &elt) const;
 
     /**
      * Returns a boolean to show if we are at the end of a word
-     * (see getNext)
-     * @returns 0 or 1 (true)
+     * (see getNext())
+     * @return true if this is the end of a word
      */
     bool isEndOfWord(const dic_elt_t &elt) const;
 
@@ -129,13 +129,13 @@ public:
      * Returns the root of the dictionary
      * @returns root element
      */
-    const dic_elt_t getRoot() const;
+    dic_elt_t getRoot() const;
 
     /**
-     * Returns the next available neighbor (see getLast)
+     * Returns the next available neighbor (see isLast())
      * @returns next dictionary element at the same depth
      */
-    const dic_elt_t getNext(const dic_elt_t &elt) const;
+    dic_elt_t getNext(const dic_elt_t &elt) const;
 
     /**
      * Returns the first element available at the next depth
@@ -143,7 +143,7 @@ public:
      * @params elt : current dictionary element
      * @returns next element (successor)
      */
-    const dic_elt_t getSucc(const dic_elt_t &elt) const;
+    dic_elt_t getSucc(const dic_elt_t &elt) const;
 
     /**
      * Find the dictionary element matching the pattern starting
@@ -183,31 +183,38 @@ public:
      * Search for benjamins
      * @param iWord: letters
      * @param oWordList: results
+     * @param iMaxResults: maximum number of returned results (0 means no limit)
      */
-    void searchBenj(const wstring &iWord, list<wstring> &oWordList) const;
+    void searchBenj(const wstring &iWord, vector<wstring> &oWordList,
+                    unsigned int iMaxResults = 0) const;
 
     /**
      * Search for all words feasible by adding a letter in front or at the end
      * @param iWord: word
      * @param oWordList: results
+     * @param iMaxResults: maximum number of returned results (0 means no limit)
      */
-    void searchRacc(const wstring &iWord, list<wstring> &oWordList) const;
+    void searchRacc(const wstring &iWord, vector<wstring> &oWordList,
+                    unsigned int iMaxResults = 0) const;
 
     /**
      * Search for crosswords
      * @param iMask: letters
      * @param oWordList: results
+     * @param iMaxResults: maximum number of returned results (0 means no limit)
      */
-    void searchCross(const wstring &iMask, list<wstring> &oWordList) const;
+    void searchCross(const wstring &iMask, vector<wstring> &oWordList,
+                     unsigned int iMaxResults = 0) const;
 
     /**
      * Search for all feasible word with "rack" plus one letter
      * @param iRack: letters
      * @param oWordlist: results
      * @param joker: true if the search must be performed when a joker is in the rack
+     * @param iMaxResults: maximum number of returned results (0 means no limit)
      */
     void search7pl1(const wstring &iRack,
-                    map<wchar_t, list<wstring> > &oWordList,
+                    map<wchar_t, vector<wstring> > &oWordList,
                     bool joker) const;
 
     /**
@@ -215,11 +222,17 @@ public:
      * @param iRegexp: regular expression
      * @param oWordList: results
      * @param iList: parameters for the search (?)
+     * @param iMaxResults: maximum number of returned results (0 means no limit)
+     * @return true if all the matching words were returned, false otherwise
+     *      (i.e. if the maximum number of results was reached, and there are
+     *      additional results)
+     * @throw InvalidRegexpException When the regular expression cannot be parsed
      */
-    void searchRegExp(const wstring &iRegexp,
-                      list<wstring> &oWordList,
-                      struct search_RegE_list_t *iList) const;
-
+    bool searchRegExp(const wstring &iRegexp,
+                      vector<wstring> &oWordList,
+                      unsigned int iMinLength,
+                      unsigned int iMaxLength,
+                      unsigned int iMaxResults = 0) const;
 
 
 private:
@@ -258,22 +271,25 @@ private:
 
     /// Helper for searchBenj()
     template <typename DAWG_EDGE>
-    void searchBenjTempl(const wstring &iWord, list<wstring> &oWordList) const;
+    void searchBenjTempl(const wstring &iWord, vector<wstring> &oWordList,
+                         unsigned int iMaxResults) const;
 
     /// Helper for searchRacc()
     template <typename DAWG_EDGE>
-    void searchRaccTempl(const wstring &iWord, list<wstring> &oWordList) const;
+    void searchRaccTempl(const wstring &iWord, vector<wstring> &oWordList,
+                         unsigned int iMaxResults) const;
 
     /// Helper for searchCross()
     template <typename DAWG_EDGE>
     void searchCrossRecTempl(struct params_cross_t *params,
-                             list<wstring> &oWordList,
-                             const DAWG_EDGE *edgeptr) const;
+                             vector<wstring> &oWordList,
+                             const DAWG_EDGE *edgeptr,
+                             unsigned int iMaxResults) const;
 
     /// Helper for search7pl1()
     template <typename DAWG_EDGE>
     void search7pl1Templ(const wstring &iRack,
-                         map<wchar_t, list<wstring> > &oWordList,
+                         map<wchar_t, vector<wstring> > &oWordList,
                          bool joker) const;
 
     /// Second helper for search7pl1()
@@ -281,20 +297,13 @@ private:
     void searchWordByLen(struct params_7plus1_t *params,
                          int i, const DAWG_EDGE *edgeptr) const;
 
-    /**
-     * Internal version of searchRegExp, needed until
-     * wide chars are supported by our regexp engine.
-     */
-    void searchRegExpInner(const string &iRegexp,
-                           list<string> &oWordList,
-                           struct search_RegE_list_t *iList) const;
-
     /// Helper for searchRegExp()
     template <typename DAWG_EDGE>
     void searchRegexpRecTempl(struct params_regexp_t *params,
                               int state,
                               const DAWG_EDGE *edgeptr,
-                              list<string> &oWordList) const;
+                              vector<wstring> &oWordList,
+                              unsigned int iMaxResults) const;
 };
 
 #endif /* _DIC_H_ */
