@@ -28,8 +28,8 @@
 #include "ai_percent.h"
 
 
-AIPercent::AIPercent(int iId, float iPercent)
-    : AIPlayer(iId), m_percent(iPercent)
+AIPercent::AIPercent(float iPercent)
+    : m_percent(iPercent)
 {
     // Ensure the decimal value of the percentage is between 0 and 1
     if (m_percent < 0)
@@ -53,9 +53,12 @@ Move AIPercent::getMove() const
 {
     if (m_results.size() == 0)
     {
-        // If there is no result, simply pass the turn
-        // XXX: it is forbidden in duplicate mode, but well, what else to do?
-        return Move(L"");
+        // If there is no result, change all the letters
+        // XXX: it is forbidden in duplicate mode (even passing is forbidden),
+        // but well, what else to do?
+        Rack rack;
+        getCurrentRack().getRack(rack);
+        return Move(rack.toString());
     }
     else
     {
