@@ -26,11 +26,11 @@
 #include "pldrack.h"
 #include "results.h"
 #include "player.h"
-#include "ai_percent.h"
 #include "game.h"
 #include "game_factory.h"
 #include "turn.h"
 #include "encoding.h"
+#include "game_exception.h"
 
 #include "debug.h"
 
@@ -71,7 +71,6 @@ void Game::helperPlayMove(unsigned int iPlayerId, const Move &iMove)
     m_history.playMove(iPlayerId, m_history.getSize(), iMove);
 
     // Points
-    debug("    helper: %d points\n", iMove.getScore());
     m_points += iMove.getScore();
 
     // For moves corresponding to a valid round, we have much more
@@ -86,18 +85,22 @@ void Game::helperPlayMove(unsigned int iPlayerId, const Move &iMove)
 
 void Game::helperPlayRound(unsigned int iPlayerId, const Round &iRound)
 {
+    // Copy the round, because we may need to modify it (case of
+    // the joker games).
+    Round round = iRound;
+
     // Before updating the bag and the board, if we are playing a "joker game",
     // we replace in the round the joker by the letter it represents
     // This is currently done by a succession of ugly hacks :-/
     if (m_variant == kJOKER)
     {
-        for (unsigned int i = 0; i < iRound.getWordLen(); i++)
+        for (unsigned int i = 0; i < round.getWordLen(); i++)
         {
-            if (iRound.isPlayedFromRack(i) && iRound.isJoker(i))
+            if (round.isPlayedFromRack(i) && round.isJoker(i))
             {
                 // Is the represented letter still available in the bag?
                 // XXX: this way to get the represented letter sucks...
-                Tile t(towupper(iRound.getTile(i).toChar()));
+                Tile t(towupper(round.getTile(i).toChar()));
                 Bag bag(m_dic);
                 realBag(bag);
                 // FIXME: realBag() does not give us a real bag in this
@@ -126,12 +129,11 @@ void Game::helperPlayRound(unsigned int iPlayerId, const Round &iRound)
 
                 if (bag.in(t))
                 {
-                    // FIXME: A const_cast sucks too...
-                    const_cast<Round&>(iRound).setTile(i, t);
-                    // FIXME: This shouldn't be necessary either, this is only
+                    round.setTile(i, t);
+                    // FIXME: This shouldn't be necessary, this is only
                     // needed because of the stupid way of handling jokers in
                     // rounds
-                    const_cast<Round&>(iRound).setJoker(i, false);
+                    round.setJoker(i, false);
                 }
 
                 // In a joker game we should have only 1 joker in the rack
@@ -145,32 +147,30 @@ void Game::helperPlayRound(unsigned int iPlayerId, const Round &iRound)
     // on the board. When going back in the game, we must only
     // replace played tiles.
     // We test a rack when it is set but tiles are left in the bag.
-    for (unsigned int i = 0; i < iRound.getWordLen(); i++)
+    for (unsigned int i = 0; i < round.getWordLen(); i++)
     {
-        if (iRound.isPlayedFromRack(i))
+        if (round.isPlayedFromRack(i))
         {
-            if (iRound.isJoker(i))
+            if (round.isJoker(i))
             {
                 m_bag.takeTile(Tile::Joker());
             }
             else
             {
-                m_bag.takeTile(iRound.getTile(i));
+                m_bag.takeTile(round.getTile(i));
             }
         }
     }
 
     // Update the board
-    m_board.addRound(m_dic, iRound);
+    m_board.addRound(m_dic, round);
 }
 
 
 int Game::back(unsigned int n)
 {
-    debug("Game::back %d\n",n);
-    // TODO: throw an exception
     if (m_history.getSize() < n)
-        return 1;
+        throw GameException("Cannot go back that far");
 
     for (unsigned int i = 0; i < n; i++)
     {
@@ -181,10 +181,8 @@ int Game::back(unsigned int n)
             continue;
 
         const Round &lastround = lastMove.getRound();
-        debug("Game::back last round %s\n",
-              convertToMb(lastround.toString()).c_str());
-        /* Remove the word from the board, and put its letters back
-         * into the bag */
+        // Remove the word from the board, and put its letters back
+        // into the bag
         m_board.removeRound(m_dic, lastround);
         for (unsigned int j = 0; j < lastround.getWordLen(); j++)
         {
@@ -196,9 +194,9 @@ int Game::back(unsigned int n)
                     m_bag.replaceTile(lastround.getTile(j));
             }
         }
-        /* Remove the points of this round */
+        // Remove the points of this round
         m_points -= lastround.getPoints();
-        /* Remove the turns */
+        // Remove the turns
         m_players[m_currPlayer]->removeLastTurn();
         m_history.removeLastTurn();
     }
@@ -206,17 +204,25 @@ int Game::back(unsigned int n)
 }
 
 
+void Game::shuffleRack()
+{
+    PlayedRack pld = getCurrentPlayer().getCurrentRack();
+    pld.shuffle();
+    m_players[currPlayer()]->setCurrentRack(pld);
+}
+
+
 void Game::realBag(Bag &ioBag) const
 {
     vector<Tile> tiles;
 
-    /* Copy the bag */
+    // Copy the bag
     ioBag = m_bag;
 
-    /* The real content of the bag depends on the game mode */
+    // The real content of the bag depends on the game mode
     if (getMode() == kFREEGAME)
     {
-        /* In freegame mode, take the letters from all the racks */
+        // In freegame mode, take the letters from all the racks
         for (unsigned int i = 0; i < getNPlayers(); i++)
         {
             getPlayer(i).getCurrentRack().getAllTiles(tiles);
@@ -281,7 +287,7 @@ int Game::helperSetRackRandom(unsigned int p, bool iCheck, set_rack_mode mode)
         }
         pld.resetNew();
     }
-    else if (mode == RACK_NEW && nold == 0 || mode == RACK_ALL)
+    else if ((mode == RACK_NEW && nold == 0) || mode == RACK_ALL)
     {
         // Replace all the tiles in the bag before choosing random ones
         vector<Tile> tiles;
@@ -297,7 +303,7 @@ int Game::helperSetRackRandom(unsigned int p, bool iCheck, set_rack_mode mode)
     }
     else
     {
-        debug("Game::helperSetRackRandom not a random mode\n");
+        throw GameException("Not a random mode");
     }
 
     // Get the tiles remaining on the rack
@@ -398,6 +404,9 @@ int Game::helperSetRackRandom(unsigned int p, bool iCheck, set_rack_mode mode)
         // Do not mark the rack as rejected if it was empty
         if (nold > 0)
             pld.setReject();
+        // Reset the number of required vowels and consonants
+        neededVowels = min;
+        neededConsonants = min;
 
         // Restore the joker if we are in a joker game
         if (jokerAdded)
@@ -450,7 +459,7 @@ int Game::helperSetRackRandom(unsigned int p, bool iCheck, set_rack_mode mode)
     pld.shuffleNew();
 
     // Post-condition check. This should never fail, of course :)
-    ASSERT(pld.checkRack(min, min), "helperSetRackRandom() is buggy!")
+    ASSERT(pld.checkRack(min, min), "helperSetRackRandom() is buggy!");
 
     // Until now we didn't modify anything except local variables.
     // Let's "commit" the changes
@@ -460,158 +469,6 @@ int Game::helperSetRackRandom(unsigned int p, bool iCheck, set_rack_mode mode)
 }
 
 
-int Game::helperSetRackRandomOld(unsigned int p, bool iCheck, set_rack_mode mode)
-{
-    ASSERT(p < getNPlayers(), "Wrong player number");
-
-    // Make a copy of the current player's rack
-    PlayedRack pld = getPlayer(p).getCurrentRack();
-    int nold = pld.getNbOld();
-
-    // Create a copy of the bag in which we can do everything we want,
-    // and take from it the tiles of the players rack so that "bag"
-    // contains the right number of tiles.
-    Bag bag(m_dic);
-    realBag(bag);
-
-    if (mode == RACK_NEW && nold != 0)
-    {
-        // We may have removed too many letters from the bag (i.e. the 'new'
-        // letters of the player)
-        vector<Tile> tiles;
-        pld.getNewTiles(tiles);
-        for (unsigned int i = 0; i < tiles.size(); i++)
-        {
-            bag.replaceTile(tiles[i]);
-        }
-        pld.resetNew();
-    }
-    else if (mode == RACK_NEW && nold == 0 || mode == RACK_ALL)
-    {
-        // Replace all the tiles in the bag before choosing random ones
-        vector<Tile> tiles;
-        pld.getAllTiles(tiles);
-        for (unsigned int i = 0; i < tiles.size(); i++)
-        {
-            bag.replaceTile(tiles[i]);
-        }
-        // RACK_NEW with an empty rack is equivalent to RACK_ALL
-        pld.reset();
-        // Do not forget to update nold, for the RACK_ALL case
-        nold = 0;
-    }
-    else
-    {
-        debug("Game::helperSetRackRandomOld not a random mode\n");
-    }
-
-    // Nothing in the rack, nothing in the bag --> end of the game
-    if (bag.getNbTiles() == 0 && pld.getNbTiles() == 0)
-    {
-        return 1;
-    }
-
-    // When iCheck is true, we must make sure that there are at least 2 vowels
-    // and 2 consonants in the rack up to the 15th turn, and at least one of
-    // them from the 16th turn.
-    // So before trying to fill the rack, we'd better make sure there is a way
-    // to complete the rack with these constraints...
-    unsigned int min = 0;
-    if (iCheck)
-    {
-        unsigned int oldc, oldv;
-
-        if (bag.getNbVowels() == 0 || bag.getNbConsonants() == 0)
-        {
-            return 1;
-        }
-        // 2 vowels and 2 consonants are needed up to the 15th turn
-        if (bag.getNbVowels() > 1 && bag.getNbConsonants() > 1
-            && m_history.getSize() < 15)
-            min = 2;
-        else
-            min = 1;
-
-        // Count the remaining consonants and vowels in the rack
-        vector<Tile> tiles;
-        pld.getOldTiles(tiles);
-        oldc = 0;
-        oldv = 0;
-        for (unsigned int i = 0; i < tiles.size(); i++)
-        {
-            if (tiles[i].isConsonant())
-                oldc++;
-            if (tiles[i].isVowel())
-                oldv++;
-        }
-
-        // RACK_SIZE - nold is the number of letters to add
-        if (min > oldc + RACK_SIZE - nold ||
-            min > oldv + RACK_SIZE - nold)
-        {
-            // We cannot fill the rack with enough vowels or consonants!
-            return 3;
-        }
-    }
-
-    // Are we dealing with a normal game or a joker game?
-    if (m_variant == kJOKER)
-    {
-        // 1) Is there already a joker in the remaining letters of the rack?
-        bool jokerFound = false;
-        vector<Tile> tiles;
-        pld.getOldTiles(tiles);
-        for (unsigned int i = 0; i < tiles.size(); i++)
-        {
-            if (tiles[i].isJoker())
-            {
-                jokerFound = true;
-                break;
-            }
-        }
-
-        // 2) If there was no joker, we add one if possible
-        if (!jokerFound && bag.in(Tile::Joker()))
-        {
-            bag.takeTile(Tile::Joker());
-            pld.addNew(Tile::Joker());
-        }
-
-        // 3) Complete the rack normally... but without any joker!
-        Tile l;
-        // FIXME: this can be an infinite loop if the only tile left in the
-        // bag is a joker!
-        while (bag.getNbTiles() != 0 && pld.getNbTiles() != RACK_SIZE)
-        {
-            l = bag.selectRandom();
-            if (!l.isJoker())
-            {
-                bag.takeTile(l);
-                pld.addNew(l);
-            }
-        }
-    }
-    else // Normal game
-    {
-        // Get new tiles from the bag
-        Tile l;
-        while (bag.getNbTiles() != 0 && pld.getNbTiles() != RACK_SIZE)
-        {
-            l = bag.selectRandom();
-            bag.takeTile(l);
-            pld.addNew(l);
-        }
-    }
-
-    if (iCheck && !pld.checkRack(min, min))
-        return 2;
-
-    m_players[p]->setCurrentRack(pld);
-
-    return 0;
-}
-
-
 bool Game::rackInBag(const Rack &iRack, const Bag &iBag) const
 {
     const vector<Tile>& allTiles = m_dic.getAllTiles();
@@ -629,7 +486,7 @@ int Game::helperSetRackManual(unsigned int p, bool iCheck, const wstring &iLette
 {
     ASSERT(p < getNPlayers(), "Wrong player number");
 
-    if (!m_dic.validateLetters(iLetters, L"+"))
+    if (!m_dic.validateLetters(iLetters, L"+-"))
         return 3;
 
     PlayedRack pld;
@@ -673,17 +530,13 @@ unsigned int Game::getNHumanPlayers() const
 }
 
 
-void Game::addHumanPlayer()
+void Game::addPlayer(Player *iPlayer)
 {
+    ASSERT(iPlayer != NULL, "Invalid player pointer in addPlayer()");
+
     // The ID of the player is its position in the m_players vector
-    m_players.push_back(new HumanPlayer(getNPlayers()));
-}
-
-
-void Game::addAIPlayer()
-{
-    // TODO: allow other percentages, and even other types of AI
-    m_players.push_back(new AIPercent(getNPlayers(), 1));
+    iPlayer->setId(getNPlayers());
+    m_players.push_back(iPlayer);
 }
 
 
@@ -722,7 +575,6 @@ int Game::checkPlayedWord(const wstring &iCoord,
     oRound.accessCoord().setFromString(iCoord);
     if (!oRound.getCoord().isValid())
     {
-        debug("game: incorrect coordinates\n");
         return 2;
     }
 
@@ -750,7 +602,7 @@ int Game::checkPlayedWord(const wstring &iCoord,
 
     // Check the word position, compute its points,
     // and specify the origin of each letter (board or rack)
-    int res = m_board.checkRound(oRound, m_history.getSize() == 0);
+    int res = m_board.checkRound(oRound);
     if (res != 0)
         return res + 4;
 
