@@ -110,11 +110,14 @@ public:
     const Player& getCurrentPlayer() const { return getPlayer(currPlayer()); };
     unsigned int getNPlayers() const { return m_players.size(); }
     unsigned int getNHumanPlayers() const;
-    virtual void addHumanPlayer();
-    // TODO: Ability to specify which kind of AI player is wanted
-    virtual void addAIPlayer();
     unsigned int currPlayer() const { return m_currPlayer; }
 
+    /**
+     * Add a player to the game.
+     * The Game object takes ownership of the given player
+     */
+    virtual void addPlayer(Player *iPlayer);
+
     /***************
      * Game handling
      ***************/
@@ -137,11 +140,12 @@ public:
      *  4: not enough letters in the rack to play the word
      *  5: word is part of a longer one
      *  6: word overwriting an existing letter
-     *  7: invalid crosscheck, or word going out of the board
+     *  7: invalid crosscheck
      *  8: word already present on the board (no new letter from the rack)
      *  9: isolated word (not connected to the rest)
      * 10: first word not horizontal
      * 11: first word not covering the H8 square
+     * 12: word going out of the board
      */
     virtual int play(const wstring &iCoord, const wstring &iWord) = 0;
 
@@ -154,6 +158,13 @@ public:
      */
     int back(unsigned int iTurn);
 
+    /// Shuffle the rack of the current player
+    void shuffleRack();
+
+    /// Return true if the player has played for the current turn
+    // XXX: not very nice API, should be a player property...
+    virtual bool hasPlayed(unsigned int player) const { return player != currPlayer(); }
+
     /***************
      * Saved games handling
      ***************/
@@ -257,20 +268,6 @@ protected:
      */
     int helperSetRackRandom(unsigned int p, bool iCheck, set_rack_mode mode);
 
-    /**
-     * Set the rack randomly for the player p
-     * Possible return values:
-     *  0: everything went fine
-     *  1: the game is over
-     *  2: the rack was checked and was not correct (try calling the
-     *     function again)
-     *  3: there is no chance to set the rack with the vowels/consonants
-     *     constraints
-     *
-     * @deprecated: use helperSetRackRandom instead
-     */
-    int helperSetRackRandomOld(unsigned int p, bool iCheck, set_rack_mode mode);
-
     /**
      * Set the rack for the player p with the given letters
      * Possible return values:
