@@ -27,6 +27,8 @@
 #include "pldrack.h"
 #include "history.h"
 
+using std::wstring;
+
 class Turn;
 
 
@@ -37,18 +39,26 @@ class Turn;
 class Player
 {
 public:
-    explicit Player(unsigned int iId);
+    explicit Player();
     virtual ~Player() {}
 
     // Pseudo RTTI
     virtual bool isHuman() const = 0;
 
+    /// Get the name of the player
+    const wstring & getName() const { return m_name; }
+    /// Set the name of the player
+    void setName(const wstring &iName) { m_name = iName; }
+
+    /// Set the ID
+    void setId(unsigned int iId) { m_id = iId; }
+
     /**************************
      * General getters
      **************************/
-    // Get the (possibly incomplete) rack of the player
+    /// Get the (possibly incomplete) rack of the player
     const PlayedRack & getCurrentRack() const;
-    // Get the previous rack
+    /// Get the previous rack
     const PlayedRack & getLastRack() const;
     /// Get the previous move (corresponding to the previous rack...)
     const Move & getLastMove() const;
@@ -56,11 +66,12 @@ public:
     void setCurrentRack(const PlayedRack &iPld);
 
     const History& getHistory() const { return m_history; }
+
     /// Remove last turn
     void removeLastTurn();
 
     /**************************
-     * Acessors for the score of the player
+     * Accessors for the score of the player
      **************************/
     // Add (or remove, if iPoints is negative) points to the score
     // of the player
@@ -84,6 +95,9 @@ private:
     /// Score of the player
     int m_score;
 
+    /// Name of the player
+    wstring m_name;
+
     /// History of the racks and rounds for the player
     History m_history;
 };
@@ -95,7 +109,7 @@ private:
 class HumanPlayer: public Player
 {
 public:
-    HumanPlayer(int iId): Player(iId) {}
+    HumanPlayer(): Player() {}
     virtual ~HumanPlayer() {}
 
     // Pseudo RTTI
