@@ -21,6 +21,13 @@
 
 #include <algorithm>
 
+#if ENABLE_NLS
+#   include <libintl.h>
+#   define _(String) gettext(String)
+#else
+#   define _(String) String
+#endif
+
 #include "dic.h"
 #include "tile.h"
 #include "rack.h"
@@ -37,25 +44,16 @@
 Training::Training(const Dictionary &iDic)
     : Game(iDic)
 {
+    // Training mode implicitly uses 1 human player
+    Game::addPlayer(new HumanPlayer);
+    m_players[0]->setName(convertToWc(_("Training")));
 }
 
 
 int Training::setRackRandom(bool iCheck, set_rack_mode mode)
 {
-#define MAX_RANDOM_TRY 5
-
-    int res;
-    int try_number = 0;
     m_results.clear();
-    do
-    {
-        res = helperSetRackRandomOld(m_currPlayer, iCheck, mode);
-        try_number ++;
-    } while (res == 2 && try_number < MAX_RANDOM_TRY);
-    // 0 : ok
-    // 1 : not enough tiles
-    // 2 : check failed (number of voyels before round 15)
-    return res;
+    return helperSetRackRandom(m_currPlayer, iCheck, mode);
 }
 
 
@@ -106,15 +104,9 @@ int Training::play(const wstring &iCoord, const wstring &iWord)
     int res = checkPlayedWord(iCoord, iWord, round);
     if (res != 0)
     {
-        debug("check returned with an error %d\n",res);
         return res;
     }
 
-    debug("play: %s %s %d\n",
-          convertToMb(round.getWord()).c_str(),
-          convertToMb(round.getCoord().toString()).c_str(),
-          round.getPoints());
-
     Move move(round);
     // Update the rack and the score of the current player
     // Player::endTurn() must be called before Game::helperPlayMove().
@@ -136,8 +128,6 @@ int Training::start()
     if (getNPlayers() != 0)
         return 1;
 
-    // Training mode implicitly uses 1 human player
-    Game::addHumanPlayer();
     m_currPlayer = 0;
     return 0;
 }
@@ -154,7 +144,6 @@ void Training::search()
     // Search for the current player
     Rack r;
     m_players[m_currPlayer]->getCurrentRack().getRack(r);
-    debug("Training::search for %s\n", convertToMb(r.toString()).c_str());
     m_results.search(m_dic, m_board, r, m_history.beforeFirstRound());
 }
 
@@ -179,17 +168,11 @@ int Training::playResult(unsigned int n)
 }
 
 
-void Training::addHumanPlayer()
+void Training::addPlayer(Player *iPlayer)
 {
-    // We are not supposed to be here...
-    ASSERT(false, "Trying to add a human player in Training mode");
-}
-
-
-void Training::addAIPlayer()
-{
-    // We are not supposed to be here...
-    ASSERT(false, "Trying to add a AI player in Training mode");
+    // Override the default behaviour to do nothing
+    // except releasing memory
+    delete iPlayer;
 }
 
 
