@@ -35,13 +35,16 @@
 #endif
 
 #include "dic.h"
-#include "regexp.h"
+#include "dic_exception.h"
 #include "game_io.h"
 #include "game_factory.h"
 #include "training.h"
 #include "duplicate.h"
 #include "freegame.h"
+#include "player.h"
+#include "ai_percent.h"
 #include "encoding.h"
+#include "game_exception.h"
 
 
 /* A static variable for holding the line. */
@@ -190,10 +193,10 @@ wchar_t * next_token_filename(wchar_t *cmd, const wchar_t *delim, wchar_t **stat
 
 void eliottxt_get_cross(const Dictionary &iDic, const wstring &iCros)
 {
-    list<wstring> wordList;
+    vector<wstring> wordList;
     iDic.searchCross(iCros, wordList);
 
-    list<wstring>::const_iterator it;
+    vector<wstring>::const_iterator it;
     for (it = wordList.begin(); it != wordList.end(); it++)
     {
         printf("  %s\n", convertToMb(*it).c_str());
@@ -404,169 +407,176 @@ void loop_training(Training &iGame)
         token = _wcstok(commande, delim, &state);
         if (token)
         {
-            switch (token[0])
+            try
             {
-                case L'?':
-                    help_training();
-                    break;
-                case L'a':
-                    display_data(iGame, delim, &state);
-                    break;
-                case L'b':
-                    token = next_token_alpha(NULL, delim, &state);
-                    if (token == NULL)
+                switch (token[0])
+                {
+                    case L'?':
                         help_training();
-                    else
-                    {
-                        const wchar_t *word = next_token_alpha(NULL, delim, &state);
-                        if (word == NULL)
+                        break;
+                    case L'a':
+                        display_data(iGame, delim, &state);
+                        break;
+                    case L'b':
+                        token = next_token_alpha(NULL, delim, &state);
+                        if (token == NULL)
                             help_training();
                         else
                         {
-                            switch (token[0])
+                            const wchar_t *word = next_token_alpha(NULL, delim, &state);
+                            if (word == NULL)
+                                help_training();
+                            else
                             {
-                                case L'b':
+                                switch (token[0])
                                 {
-                                    list<wstring> wordList;
-                                    iGame.getDic().searchBenj(word, wordList);
-                                    list<wstring>::const_iterator it;
-                                    for (it = wordList.begin(); it != wordList.end(); ++it)
-                                        cout << convertToMb(*it) << endl;
-                                    break;
-                                }
-                                case L'p':
-                                {
-                                    map<wchar_t, list<wstring> > wordMap;
-                                    iGame.getDic().search7pl1(word, wordMap, false);
-                                    map<wchar_t, list<wstring> >::const_iterator it;
-                                    for (it = wordMap.begin(); it != wordMap.end(); ++it)
-                                    {
-                                        if (it->first)
-                                            cout << "+" << convertToMb(it->first) << endl;
-                                        list<wstring>::const_iterator itWord;;
-                                        for (itWord = it->second.begin(); itWord != it->second.end(); itWord++)
+                                    case L'b':
                                         {
-                                            cout << "  " << convertToMb(*itWord) << endl;
+                                            vector<wstring> wordList;
+                                            iGame.getDic().searchBenj(word, wordList);
+                                            vector<wstring>::const_iterator it;
+                                            for (it = wordList.begin(); it != wordList.end(); ++it)
+                                                cout << convertToMb(*it) << endl;
+                                            break;
+                                        }
+                                    case L'p':
+                                        {
+                                            map<wchar_t, vector<wstring> > wordMap;
+                                            iGame.getDic().search7pl1(word, wordMap, false);
+                                            map<wchar_t, vector<wstring> >::const_iterator it;
+                                            for (it = wordMap.begin(); it != wordMap.end(); ++it)
+                                            {
+                                                if (it->first)
+                                                    cout << "+" << convertToMb(it->first) << endl;
+                                                vector<wstring>::const_iterator itWord;;
+                                                for (itWord = it->second.begin(); itWord != it->second.end(); itWord++)
+                                                {
+                                                    cout << "  " << convertToMb(*itWord) << endl;
+                                                }
+                                            }
+                                            break;
+                                        }
+                                    case L'r':
+                                        {
+                                            vector<wstring> wordList;
+                                            iGame.getDic().searchRacc(word, wordList);
+                                            vector<wstring>::const_iterator it;
+                                            for (it = wordList.begin(); it != wordList.end(); ++it)
+                                                cout << convertToMb(*it) << endl;
+                                            break;
                                         }
-                                    }
-                                    break;
-                                }
-                                case L'r':
-                                {
-                                    list<wstring> wordList;
-                                    iGame.getDic().searchRacc(word, wordList);
-                                    list<wstring>::const_iterator it;
-                                    for (it = wordList.begin(); it != wordList.end(); ++it)
-                                        cout << convertToMb(*it) << endl;
-                                    break;
                                 }
                             }
                         }
-                    }
-                    break;
-                case L'd':
-                    token = next_token_alpha(NULL, delim, &state);
-                    if (token == NULL)
-                        help_training();
-                    else
-                    {
-                        if (iGame.getDic().searchWord(token))
-                        {
-                            printf("le mot -%s- existe\n",
-                                   convertToMb(token).c_str());
-                        }
-                        else
-                        {
-                            printf("le mot -%s- n'existe pas\n",
-                                   convertToMb(token).c_str());
-                        }
-                    }
-                    break;
-                case L'j':
-                    token = next_token_alpha(NULL, delim, &state);
-                    if (token == NULL)
-                        help_training();
-                    else
-                    {
-                        int res;
-                        wchar_t *coord = next_token_alphanum(NULL, delim, &state);
-                        if (coord == NULL)
-                        {
+                        break;
+                    case L'd':
+                        token = next_token_alpha(NULL, delim, &state);
+                        if (token == NULL)
                             help_training();
-                            break;
-                        }
-                        if ((res = iGame.play(coord, token)) != 0)
-                        {
-                            fprintf(stdout, "Mot incorrect ou mal plac (%i)\n",
-                                    res);
-                            break;
-                        }
-                    }
-                    break;
-                case L'n':
-                    token = next_token_digit(NULL, delim, &state);
-                    if (token == NULL)
-                        help_training();
-                    else
-                    {
-                        int n = _wtoi(token);
-                        if (n <= 0)
-                        {
-                            iGame.back(n == 0 ? 1 : -n);
-                        }
                         else
                         {
-                            if (iGame.playResult(--n))
-                                printf("mauvais argument\n");
+                            if (iGame.getDic().searchWord(token))
+                            {
+                                printf("le mot -%s- existe\n",
+                                       convertToMb(token).c_str());
+                            }
+                            else
+                            {
+                                printf("le mot -%s- n'existe pas\n",
+                                       convertToMb(token).c_str());
+                            }
                         }
-                    }
-                    break;
-                case L'r':
-                    iGame.search();
-                    break;
-                case L't':
-                    token = next_token_alphaplusjoker(NULL, delim, &state);
-                    if (token == NULL)
-                        help_training();
-                    else
-                        if (iGame.setRackManual(0, token))
-                            printf("le sac ne contient pas assez de lettres\n");
-                    break;
-                case L'x':
-                    token = next_token_cross(NULL, delim, &state);
-                    if (token == NULL)
-                        help_training();
-                    else
-                        eliottxt_get_cross(iGame.getDic(), token);
-                    break;
-                case L'*':
-                    iGame.setRackRandom(false, Game::RACK_ALL);
-                    break;
-                case L'+':
-                    iGame.setRackRandom(false, Game::RACK_NEW);
-                    break;
-                case L's':
-                    token = next_token_filename(NULL, delim, &state);
-                    if (token != NULL)
-                    {
-                        string filename = convertToMb(token);
-                        ofstream fout(filename.c_str());
-                        if (fout.rdstate() == ios::failbit)
+                        break;
+                    case L'j':
+                        token = next_token_alpha(NULL, delim, &state);
+                        if (token == NULL)
+                            help_training();
+                        else
                         {
-                            printf("impossible d'ouvrir %s\n",
-                                   filename.c_str());
-                            break;
+                            int res;
+                            wchar_t *coord = next_token_alphanum(NULL, delim, &state);
+                            if (coord == NULL)
+                            {
+                                help_training();
+                                break;
+                            }
+                            if ((res = iGame.play(coord, token)) != 0)
+                            {
+                                fprintf(stdout, "Mot incorrect ou mal plac (%i)\n",
+                                        res);
+                                break;
+                            }
                         }
-                        iGame.save(fout);
-                        fout.close();
-                    }
-                    break;
-                case L'q':
-                    quit = 1;
-                    break;
-                default:
-                    printf("commande inconnue\n");
-                    break;
+                        break;
+                    case L'n':
+                        token = next_token_digit(NULL, delim, &state);
+                        if (token == NULL)
+                            help_training();
+                        else
+                        {
+                            int n = _wtoi(token);
+                            if (n <= 0)
+                            {
+                                iGame.back(n == 0 ? 1 : -n);
+                            }
+                            else
+                            {
+                                if (iGame.playResult(--n))
+                                    printf("mauvais argument\n");
+                            }
+                        }
+                        break;
+                    case L'r':
+                        iGame.search();
+                        break;
+                    case L't':
+                        token = next_token_alphaplusjoker(NULL, delim, &state);
+                        if (token == NULL)
+                            help_training();
+                        else
+                            if (iGame.setRackManual(0, token))
+                                printf("le sac ne contient pas assez de lettres\n");
+                        break;
+                    case L'x':
+                        token = next_token_cross(NULL, delim, &state);
+                        if (token == NULL)
+                            help_training();
+                        else
+                            eliottxt_get_cross(iGame.getDic(), token);
+                        break;
+                    case L'*':
+                        iGame.setRackRandom(false, Game::RACK_ALL);
+                        break;
+                    case L'+':
+                        iGame.setRackRandom(false, Game::RACK_NEW);
+                        break;
+                    case L's':
+                        token = next_token_filename(NULL, delim, &state);
+                        if (token != NULL)
+                        {
+                            string filename = convertToMb(token);
+                            ofstream fout(filename.c_str());
+                            if (fout.rdstate() == ios::failbit)
+                            {
+                                printf("impossible d'ouvrir %s\n",
+                                       filename.c_str());
+                                break;
+                            }
+                            iGame.save(fout);
+                            fout.close();
+                        }
+                        break;
+                    case L'q':
+                        quit = 1;
+                        break;
+                    default:
+                        printf("commande inconnue\n");
+                        break;
+                }
+            }
+            catch (GameException &e)
+            {
+                printf("%s\n", e.what());
             }
         }
     }
@@ -590,84 +600,91 @@ void loop_freegame(FreeGame &iGame)
         token = _wcstok(commande, delim, &state);
         if (token)
         {
-            switch (token[0])
+            try
             {
-                case L'?':
-                    help_freegame();
-                    break;
-                case L'a':
-                    display_data(iGame, delim, &state);
-                    break;
-                case L'd':
-                    token = next_token_alpha(NULL, delim, &state);
-                    if (token == NULL)
+                switch (token[0])
+                {
+                    case L'?':
                         help_freegame();
-                    else
-                    {
-                        if (iGame.getDic().searchWord(token))
-                        {
-                            printf("le mot -%s- existe\n",
-                                   convertToMb(token).c_str());
-                        }
+                        break;
+                    case L'a':
+                        display_data(iGame, delim, &state);
+                        break;
+                    case L'd':
+                        token = next_token_alpha(NULL, delim, &state);
+                        if (token == NULL)
+                            help_freegame();
                         else
                         {
-                            printf("le mot -%s- n'existe pas\n",
-                                   convertToMb(token).c_str());
+                            if (iGame.getDic().searchWord(token))
+                            {
+                                printf("le mot -%s- existe\n",
+                                       convertToMb(token).c_str());
+                            }
+                            else
+                            {
+                                printf("le mot -%s- n'existe pas\n",
+                                       convertToMb(token).c_str());
+                            }
                         }
-                    }
-                    break;
-                case L'j':
-                    token = next_token_alpha(NULL, delim, &state);
-                    if (token == NULL)
-                        help_freegame();
-                    else
-                    {
-                        int res;
-                        wchar_t *coord = next_token_alphanum(NULL, delim, &state);
-                        if (coord == NULL)
-                        {
-                            help_freegame();
-                            break;
-                        }
-                        if ((res = iGame.play(coord, token)) != 0)
-                        {
-                            fprintf(stdout, "Mot incorrect ou mal plac (%i)\n",
-                                    res);
-                            break;
-                        }
-                    }
-                    break;
-               case L'p':
-                    token = next_token_alpha(NULL, delim, &state);
-                    /* You can pass your turn without changing any letter */
-                    if (token == NULL)
-                        token = L"";
-
-                    if (iGame.pass(token) != 0)
                         break;
-                    break;
-                case L's':
-                    token = next_token_filename(NULL, delim, &state);
-                    if (token != NULL)
-                    {
-                        string filename = convertToMb(token);
-                        ofstream fout(filename.c_str());
-                        if (fout.rdstate() == ios::failbit)
+                    case L'j':
+                        token = next_token_alpha(NULL, delim, &state);
+                        if (token == NULL)
+                            help_freegame();
+                        else
                         {
-                            printf("impossible d'ouvrir %s\n",
-                                   filename.c_str());
-                            break;
+                            int res;
+                            wchar_t *coord = next_token_alphanum(NULL, delim, &state);
+                            if (coord == NULL)
+                            {
+                                help_freegame();
+                                break;
+                            }
+                            if ((res = iGame.play(coord, token)) != 0)
+                            {
+                                fprintf(stdout, "Mot incorrect ou mal plac (%i)\n",
+                                        res);
+                                break;
+                            }
                         }
-                        iGame.save(fout);
-                        fout.close();
-                    }
-                    break;
-                case L'q':
-                    quit = 1;
-                    break;
-                default:
-                    printf("commande inconnue\n");
-                    break;
+                        break;
+                    case L'p':
+                        token = next_token_alpha(NULL, delim, &state);
+                        /* You can pass your turn without changing any letter */
+                        if (token == NULL)
+                            token = L"";
+
+                        if (iGame.pass(token) != 0)
+                            break;
+                        break;
+                    case L's':
+                        token = next_token_filename(NULL, delim, &state);
+                        if (token != NULL)
+                        {
+                            string filename = convertToMb(token);
+                            ofstream fout(filename.c_str());
+                            if (fout.rdstate() == ios::failbit)
+                            {
+                                printf("impossible d'ouvrir %s\n",
+                                       filename.c_str());
+                                break;
+                            }
+                            iGame.save(fout);
+                            fout.close();
+                        }
+                        break;
+                    case L'q':
+                        quit = 1;
+                        break;
+                    default:
+                        printf("commande inconnue\n");
+                        break;
+                }
+            }
+            catch (GameException &e)
+            {
+                printf("%s\n", e.what());
             }
         }
     }
@@ -691,92 +708,99 @@ void loop_duplicate(Duplicate &iGame)
         token = _wcstok(commande, delim, &state);
         if (token)
         {
-            switch (token[0])
+            try
             {
-                case L'?':
-                    help_duplicate();
-                    break;
-                case L'a':
-                    display_data(iGame, delim, &state);
-                    break;
-                case L'd':
-                    token = next_token_alpha(NULL, delim, &state);
-                    if (token == NULL)
+                switch (token[0])
+                {
+                    case L'?':
                         help_duplicate();
-                    else
-                    {
-                        if (iGame.getDic().searchWord(token))
-                        {
-                            printf("le mot -%s- existe\n",
-                                   convertToMb(token).c_str());
-                        }
+                        break;
+                    case L'a':
+                        display_data(iGame, delim, &state);
+                        break;
+                    case L'd':
+                        token = next_token_alpha(NULL, delim, &state);
+                        if (token == NULL)
+                            help_duplicate();
                         else
                         {
-                            printf("le mot -%s- n'existe pas\n",
-                                   convertToMb(token).c_str());
+                            if (iGame.getDic().searchWord(token))
+                            {
+                                printf("le mot -%s- existe\n",
+                                       convertToMb(token).c_str());
+                            }
+                            else
+                            {
+                                printf("le mot -%s- n'existe pas\n",
+                                       convertToMb(token).c_str());
+                            }
                         }
-                    }
-                    break;
-                case L'j':
-                    token = next_token_alpha(NULL, delim, &state);
-                    if (token == NULL)
-                        help_duplicate();
-                    else
-                    {
-                        int res;
-                        wchar_t *coord = next_token_alphanum(NULL, delim, &state);
-                        if (coord == NULL)
-                        {
+                        break;
+                    case L'j':
+                        token = next_token_alpha(NULL, delim, &state);
+                        if (token == NULL)
                             help_duplicate();
-                            break;
-                        }
-                        if ((res = iGame.play(coord, token)) != 0)
+                        else
                         {
-                            fprintf(stdout, "Mot incorrect ou mal plac (%i)\n",
-                                    res);
-                            break;
+                            int res;
+                            wchar_t *coord = next_token_alphanum(NULL, delim, &state);
+                            if (coord == NULL)
+                            {
+                                help_duplicate();
+                                break;
+                            }
+                            if ((res = iGame.play(coord, token)) != 0)
+                            {
+                                fprintf(stdout, "Mot incorrect ou mal plac (%i)\n",
+                                        res);
+                                break;
+                            }
                         }
-                    }
-                    break;
-                case L'n':
-                    token = next_token_digit(NULL, delim, &state);
-                    if (token == NULL)
-                        help_duplicate();
-                    else
-                    {
-                        int n = _wtoi(token);
-                        if (n < 0 || n >= (int)iGame.getNPlayers())
+                        break;
+                    case L'n':
+                        token = next_token_digit(NULL, delim, &state);
+                        if (token == NULL)
+                            help_duplicate();
+                        else
                         {
-                            fprintf(stderr, "Numro de joueur invalide\n");
-                            break;
+                            int n = _wtoi(token);
+                            if (n < 0 || n >= (int)iGame.getNPlayers())
+                            {
+                                fprintf(stderr, "Numro de joueur invalide\n");
+                                break;
+                            }
+                            int res = iGame.setPlayer(_wtoi(token));
+                            if (res == 1)
+                                fprintf(stderr, "Impossible de choisir un joueur non humain\n");
                         }
-                        int res = iGame.setPlayer(_wtoi(token));
-                        if (res == 1)
-                            fprintf(stderr, "Impossible de choisir un joueur non humain\n");
-                    }
-                    break;
-                case L's':
-                    token = next_token_filename(NULL, delim, &state);
-                    if (token != NULL)
-                    {
-                        string filename = convertToMb(token);
-                        ofstream fout(filename.c_str());
-                        if (fout.rdstate() == ios::failbit)
+                        break;
+                    case L's':
+                        token = next_token_filename(NULL, delim, &state);
+                        if (token != NULL)
                         {
-                            printf("impossible d'ouvrir %s\n",
-                                   filename.c_str());
-                            break;
+                            string filename = convertToMb(token);
+                            ofstream fout(filename.c_str());
+                            if (fout.rdstate() == ios::failbit)
+                            {
+                                printf("impossible d'ouvrir %s\n",
+                                       filename.c_str());
+                                break;
+                            }
+                            iGame.save(fout);
+                            fout.close();
                         }
-                        iGame.save(fout);
-                        fout.close();
-                    }
-                    break;
-                case L'q':
-                    quit = 1;
-                    break;
-                default:
-                    printf("commande inconnue\n");
-                    break;
+                        break;
+                    case L'q':
+                        quit = 1;
+                        break;
+                    default:
+                        printf("commande inconnue\n");
+                        break;
+                }
+            }
+            catch (GameException &e)
+            {
+                printf("%s\n", e.what());
             }
         }
     }
@@ -784,54 +808,7 @@ void loop_duplicate(Duplicate &iGame)
 }
 
 
-void eliot_regexp_build_default_llist(const Dictionary &iDic,
-                                      struct search_RegE_list_t &llist)
-{
-    memset(&llist, 0, sizeof(llist));
-
-    llist.minlength = 1;
-    llist.maxlength = 15;
-
-    llist.symbl[0] = RE_ALL_MATCH;
-    llist.symbl[1] = RE_VOWL_MATCH;
-    llist.symbl[2] = RE_CONS_MATCH;
-    llist.symbl[3] = RE_USR1_MATCH;
-    llist.symbl[5] = RE_USR2_MATCH;
-
-    llist.valid[0] = 1; // all letters
-    llist.valid[1] = 1; // vowels
-    llist.valid[2] = 1; // consonants
-    llist.valid[3] = 0; // user defined list 1
-    llist.valid[4] = 0; // user defined list 2
-
-    for (int i = 0; i < DIC_SEARCH_REGE_LIST; i++)
-    {
-        memset(llist.letters[i], 0, sizeof(llist.letters[i]));
-    }
-
-    const vector<Tile>& allTiles = iDic.getAllTiles();
-    vector<Tile>::const_iterator it;
-    for (it = allTiles.begin(); it != allTiles.end(); it++)
-    {
-        if (! it->isJoker() && ! it->isEmpty())
-        {
-            // all tiles
-            llist.letters[0][it->toCode()] = 1;
-            // vowels
-            if (it->isVowel())
-            {
-                llist.letters[1][it->toCode()] = 1;
-            }
-            // consonants
-            if (it->isConsonant())
-            {
-                llist.letters[2][it->toCode()] = 1;
-            }
-        }
-    }
-}
-
-void eliot_regexp(const Dictionary& iDic, wchar_t __attribute__((unused)) *cmd,
+void eliot_regexp(const Dictionary& iDic,
                   const wchar_t *delim, wchar_t **state)
 {
     /*
@@ -842,11 +819,6 @@ void eliot_regexp(const Dictionary& iDic, wchar_t __attribute__((unused)) *cmd,
     printf("          {3} longueur maximum d'un mot\n");
     */
 
-#define DIC_RE_MAX (3*DIC_WORD_MAX) // yes, it's 3
-
-    struct search_RegE_list_t llist;
-    eliot_regexp_build_default_llist(iDic, llist);
-
     wchar_t *regexp = _wcstok(NULL, delim, state);
     wchar_t *cnres = _wcstok(NULL, delim, state);
     wchar_t *clmin = _wcstok(NULL, delim, state);
@@ -856,16 +828,11 @@ void eliot_regexp(const Dictionary& iDic, wchar_t __attribute__((unused)) *cmd,
     {
         return;
     }
-    int nres = cnres ? _wtoi(cnres) : 50;
-    int lmin = clmin ? _wtoi(clmin) : 1;
-    int lmax = clmax ? _wtoi(clmax) : DIC_WORD_MAX - 1;
+    unsigned int nres = cnres ? _wtoi(cnres) : 50;
+    unsigned int lmin = clmin ? _wtoi(clmin) : 1;
+    unsigned int lmax = clmax ? _wtoi(clmax) : DIC_WORD_MAX - 1;
 
-    if (lmax <= (DIC_WORD_MAX - 1) && lmin >= 1 && lmin <= lmax)
-    {
-        llist.minlength = lmin;
-        llist.maxlength = lmax;
-    }
-    else
+    if (lmax > (DIC_WORD_MAX - 1) || lmin < 1 || lmin > lmax)
     {
         printf("bad length -%s,%s-\n", (const char*)clmin, (const char*)clmax);
         return;
@@ -874,17 +841,23 @@ void eliot_regexp(const Dictionary& iDic, wchar_t __attribute__((unused)) *cmd,
     printf("search for %s (%d,%d,%d)\n", convertToMb(regexp).c_str(),
            nres, lmin, lmax);
 
-    list<wstring> wordList;
-    iDic.searchRegExp(regexp, wordList, &llist);
+    vector<wstring> wordList;
+    try
+    {
+        iDic.searchRegExp(regexp, wordList, lmin, lmax, nres);
+    }
+    catch (InvalidRegexpException &e)
+    {
+        printf("Invalid regular expression: %s\n", e.what());
+        return;
+    }
 
-    int nresult = 0;
-    list<wstring>::const_iterator it;
-    for (it = wordList.begin(); it != wordList.end() && nresult < nres; it++)
+    vector<wstring>::const_iterator it;
+    for (it = wordList.begin(); it != wordList.end(); it++)
     {
         printf("%s\n", convertToMb(*it).c_str());
-        nresult++;
     }
-    printf("%d printed results\n", nresult);
+    printf("%d printed results\n", wordList.size());
 }
 
 
@@ -959,7 +932,7 @@ void main_loop(const Dictionary &iDic)
                     }
                     Duplicate *game = GameFactory::Instance()->createDuplicate(iDic);
                     for (i = 0; i < _wtoi(token); i++)
-                        game->addHumanPlayer();
+                        game->addPlayer(new HumanPlayer);
                     token = next_token_digit(NULL, delim, &state);
                     if (token == NULL)
                     {
@@ -967,7 +940,7 @@ void main_loop(const Dictionary &iDic)
                         break;
                     }
                     for (i = 0; i < _wtoi(token); i++)
-                        game->addAIPlayer();
+                        game->addPlayer(new AIPercent(1));
                     game->start();
                     loop_duplicate(*game);
                     GameFactory::Instance()->releaseGame(*game);
@@ -985,7 +958,7 @@ void main_loop(const Dictionary &iDic)
                     }
                     FreeGame *game = GameFactory::Instance()->createFreeGame(iDic);
                     for (i = 0; i < _wtoi(token); i++)
-                        game->addHumanPlayer();
+                        game->addPlayer(new HumanPlayer);
                     token = next_token_digit(NULL, delim, &state);
                     if (token == NULL)
                     {
@@ -993,7 +966,7 @@ void main_loop(const Dictionary &iDic)
                         break;
                     }
                     for (i = 0; i < _wtoi(token); i++)
-                        game->addAIPlayer();
+                        game->addPlayer(new AIPercent(1));
                     game->start();
                     loop_freegame(*game);
                     GameFactory::Instance()->releaseGame(*game);
@@ -1003,8 +976,8 @@ void main_loop(const Dictionary &iDic)
                 {
                     // New duplicate game
                     Duplicate *game = GameFactory::Instance()->createDuplicate(iDic);
-                    game->addHumanPlayer();
-                    game->addAIPlayer();
+                    game->addPlayer(new HumanPlayer);
+                    game->addPlayer(new AIPercent(1));
                     game->start();
                     loop_duplicate(*game);
                     GameFactory::Instance()->releaseGame(*game);
@@ -1014,8 +987,8 @@ void main_loop(const Dictionary &iDic)
                 {
                     // New free game
                     FreeGame *game = GameFactory::Instance()->createFreeGame(iDic);
-                    game->addHumanPlayer();
-                    game->addAIPlayer();
+                    game->addPlayer(new HumanPlayer);
+                    game->addPlayer(new AIPercent(1));
                     game->start();
                     loop_freegame(*game);
                     GameFactory::Instance()->releaseGame(*game);
@@ -1023,7 +996,7 @@ void main_loop(const Dictionary &iDic)
                 }
                 case L'x':
                     // Regular expression tests
-                    eliot_regexp(iDic, NULL, delim, &state);
+                    eliot_regexp(iDic, delim, &state);
                     break;
                 case L'q':
                     quit = 1;
