@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (C) 2005 Eliot
+ * Copyright (C) 2005-2008 Eliot
  * Authors: Olivier Teuliere  <ipkiss@via.ecp.fr>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,9 +24,14 @@
 #else
 #   define _(String) String
 #endif
+#ifdef WIN32
+#   include <windows.h>
+#endif
 
 #include <ctype.h>
+#include <cstring> // For strlen
 #include <fstream>
+#include <algorithm>
 
 #include "ncurses.h"
 #include "dic.h"
@@ -266,14 +271,27 @@ void CursesIntf::drawBoard(WINDOW *win, int y, int x) const
 
 void CursesIntf::drawScoresRacks(WINDOW *win, int y, int x) const
 {
+    // Compute the longest player name
+    size_t longest = 0;
+    for (unsigned int i = 0; i < m_game->getNPlayers(); i++)
+    {
+        longest = std::max(longest, m_game->getPlayer(i).getName().size());
+    }
+
     Box box(win, y, x, m_game->getNPlayers() + 2, 25);
     box.draw(_("Scores"));
+    // Magic formula to truncate too long names
+    unsigned int maxForScores =
+        std::min(longest,
+                 box.getWidth() - strlen(_("%s: %d")) - 1);
     for (unsigned int i = 0; i < m_game->getNPlayers(); i++)
     {
         if (m_game->getMode() != Game::kTRAINING && i == m_game->currPlayer())
             attron(A_BOLD);
-        mvwprintw(win, y + i + 1, x + 2,
-                  _("Player %d: %d"), i, m_game->getPlayer(i).getPoints());
+        mvwprintw(win, y + i + 1, x + 2, _("%s: %d"),
+                  truncOrPad(convertToMb(m_game->getPlayer(i).getName()),
+                             maxForScores).c_str(),
+                  m_game->getPlayer(i).getPoints());
         if (m_game->getMode() != Game::kTRAINING && i == m_game->currPlayer())
             attroff(A_BOLD);
     }
@@ -283,13 +301,19 @@ void CursesIntf::drawScoresRacks(WINDOW *win, int y, int x) const
 
     Box box2(win, y + yOff, x, m_game->getNPlayers() + 2, 25);
     box2.draw(_("Racks"));
+    // Magic formula to truncate too long names
+    unsigned int maxForRacks =
+        std::min(longest,
+                 box.getWidth() - strlen(_("%s: %ls")) - 4);
     for (unsigned int i = 0; i < m_game->getNPlayers(); i++)
     {
         if (m_game->getMode() != Game::kTRAINING && i == m_game->currPlayer())
             attron(A_BOLD);
         wstring rack = m_game->getPlayer(i).getCurrentRack().toString(PlayedRack::RACK_SIMPLE);
-        mvwprintw(win, y + yOff + i + 1, x + 2,
-                  _("Player %d: %ls"), i, rack.c_str());
+        mvwprintw(win, y + yOff + i + 1, x + 2, _("%s: %ls"),
+                  truncOrPad(convertToMb(m_game->getPlayer(i).getName()),
+                             maxForRacks).c_str(),
+                  rack.c_str());
         if (m_game->getMode() != Game::kTRAINING && i == m_game->currPlayer())
             attroff(A_BOLD);
         // Force to refresh the whole rack
@@ -1097,7 +1121,18 @@ int main(int argc, char ** argv)
 
 #if ENABLE_NLS
     // Set the message domain
-    bindtextdomain(PACKAGE, LOCALEDIR);
+#ifdef WIN32
+    // Get the absolute path, as returned by GetFullPathName()
+    char baseDir[MAX_PATH];
+    GetFullPathName(argv[0], MAX_PATH, baseDir, NULL);
+    char *pos = strrchr(baseDir, L'\\');
+    if (pos)
+        *pos = '\0';
+    const string localeDir = baseDir + string("\\locale");
+#else
+    static const string localeDir = LOCALEDIR;
+#endif
+    bindtextdomain(PACKAGE, localeDir.c_str());
     textdomain(PACKAGE);
 #endif
 
