@@ -14,9 +14,7 @@
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
-
-/* $Id: confsearch.h,v 1.1 2004/04/08 09:43:06 afrab Exp $ */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 #ifndef _CONFSEARCH_H
 #define _CONFSEARCH_H
@@ -24,28 +22,29 @@
 #include "wx/button.h"
 #include "wx/dialog.h"
 #include "wx/checkbox.h"
+#include "configdb.h"
 
 class ConfSearchDlg : public wxDialog
 {
 private:
   ConfigDB config;
-  
+
   wxButton *bok;
   wxButton *bcancel;
-  
+
   wxCheckBox *joker_searching;
   wxCheckBox *rack_checking;
 
   void readconf();
   void writeconf();
-  
+
 public:
 
   ConfSearchDlg(wxWindow* parent);
   void OnButtonOk    (wxCommandEvent& event);
   void OnButtonCancel(wxCommandEvent& event);
   void OnCloseWindow (wxCloseEvent& event);
-  
+
   DECLARE_EVENT_TABLE()
 };
 #endif
