@@ -1,24 +1,22 @@
 /* Eliot                                                                     */
 /* Copyright (C) 1999  Antoine Fraboulet                                     */
-/* Antoine.Fraboulet@free.fr                                                 */
 /*                                                                           */
-/* This program is free software; you can redistribute it and/or modify      */
+/* This file is part of Eliot.                                               */
+/*                                                                           */
+/* Eliot is free software; you can redistribute it and/or modify             */
 /* it under the terms of the GNU General Public License as published by      */
 /* the Free Software Foundation; either version 2 of the License, or         */
 /* (at your option) any later version.                                       */
 /*                                                                           */
-/* This program is distributed in the hope that it will be useful,           */
+/* Eliot is distributed in the hope that it will be useful,                  */
 /* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
 /* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
 /* GNU General Public License for more details.                              */
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
-/* $Id: printout.h,v 1.1 2004/04/08 09:43:06 afrab Exp $ */
-
-// -*- C++ -*-
 #ifndef _PRINTOUT_H
 #define _PRINTOUT_H
 
@@ -28,23 +26,33 @@
 class GamePrintout : public wxPrintout
 {
 private:
-  Game game;
-  ConfigDB config;
+    Game& m_game;
+    ConfigDB config;
 
-  void SetSpaces(wxString*, int);
-  void DrawStringJustif(wxDC*,wxString*,long,long,long,enum Justif, int);
-  void DrawHeadingLine(wxDC*, long, float);
-  void DrawTextLine(wxDC*, int, long, long, float);
-  void DrawGameLines(wxDC*, long, long, float, float, float);
+    void SetSpaces(wxString*, int);
+    void DrawStringJustif(wxDC*,wxString*,long,long,long,enum Justif, int);
+    void DrawHeadingLine(wxDC*, long, float);
+    void DrawTextLine(wxDC*, int, long, long, float);
+    void DrawGameLines(wxDC*, long, long, float, float, float);
 public:
 
-  GamePrintout(Game g, char* title= APPNAME) : wxPrintout(title) { game = g; }
-  
-  bool OnPrintPage(int);
-  bool HasPage(int);
-  bool OnBeginDocument(int startPage, int endPage);
-  void GetPageInfo(int *minPage, int *maxPage, int *selPageFrom, int *selPageTo);
-  void DrawPage(wxDC *dc);
+    GamePrintout(Game& iGame, char* title = APPNAME)
+        : wxPrintout(wxU(title)), m_game(iGame) {}
+
+    bool OnPrintPage(int);
+    bool HasPage(int);
+    bool OnBeginDocument(int startPage, int endPage);
+    void GetPageInfo(int *minPage, int *maxPage, int *selPageFrom, int *selPageTo);
+    void DrawPage(wxDC *dc);
 };
 
 #endif
+
+/****************************************************************/
+/****************************************************************/
+
+/// Local Variables:
+/// mode: c++
+/// mode: hs-minor
+/// c-basic-offset: 4
+/// End:
