@@ -29,7 +29,7 @@
 
 #include "ewx.h"
 #include "dic.h"
-#include "regexp.h"
+#include "dic_exception.h"
 #include "searchpanel.h"
 #include "tile.h"
 #include "configdb.h"
@@ -151,12 +151,12 @@ PCross::compute_enter(wxCommandEvent&)
     wchar_t rack[DIC_WORD_MAX];
     wcsncpy(rack, t->GetValue().wc_str(), DIC_WORD_MAX);
 
-    list<wstring> wordList;
+    vector<wstring> wordList;
     dic->searchCross(rack, wordList);
 
     int resnum = 0;
     wxString *res = new wxString[wordList.size()];
-    list<wstring>::const_iterator it;
+    vector<wstring>::const_iterator it;
     for (it = wordList.begin(); it != wordList.end(); it++)
         res[resnum++] =  wxU(it->c_str());
     l->Set(resnum,res);
@@ -193,12 +193,12 @@ PPlus1::compute_enter(wxCommandEvent&)
     }
 
     wstring rack = t->GetValue().wc_str();
-    map<wchar_t, list<wstring> > wordList;
+    map<wchar_t, vector<wstring> > wordList;
     dic->search7pl1(rack, wordList, true);
 
     // Count the results
     int sum = 0;
-    map<wchar_t, list<wstring> >::const_iterator it;
+    map<wchar_t, vector<wstring> >::const_iterator it;
     for (it = wordList.begin(); it != wordList.end(); it++)
     {
         if (it->first)
@@ -212,7 +212,7 @@ PPlus1::compute_enter(wxCommandEvent&)
     {
         if (it->first)
             res[resnum++] = wxString(wxT("+")) + wxU((wxString)it->first);
-        list<wstring>::const_iterator itWord;
+        vector<wstring>::const_iterator itWord;
         for (itWord = it->second.begin(); itWord != it->second.end(); itWord++)
         {
             res[resnum++] = wxString(wxT("  ")) + wxU(itWord->c_str());
@@ -229,69 +229,17 @@ PPlus1::compute_enter(wxCommandEvent&)
 
 class PRegExp : public SimpleSearchPanel
 {
-protected:
+private:
   wxTextCtrl                *omin;
   wxTextCtrl                *omax;
-  struct search_RegE_list_t llist;
 
-  virtual void build_letter_lists();
-  virtual void panel_options();
+  void panel_options();
 public:
   void compute_char(wxCommandEvent&) {}
   void compute_enter(wxCommandEvent&);
   PRegExp(wxWindow* parent, int id, const Dictionary &d) : SimpleSearchPanel(parent,id,d) { panel_build(); }
 };
 
-void
-PRegExp::build_letter_lists()
-{
-  int i;
-  std::list<Tile> all_tiles;
-
-  memset (&llist,0,sizeof(llist));
-
-  llist.minlength = 1;
-  llist.maxlength = 15;
-
-  llist.symbl[0] = RE_ALL_MATCH;
-  llist.symbl[1] = RE_VOWL_MATCH;
-  llist.symbl[2] = RE_CONS_MATCH;
-  llist.symbl[3] = RE_USR1_MATCH;
-  llist.symbl[5] = RE_USR2_MATCH;
-
-  llist.valid[0] = 1; // all letters
-  llist.valid[1] = 1; // vowels
-  llist.valid[2] = 1; // consonants
-  llist.valid[3] = 0; // user defined list 1
-  llist.valid[4] = 0; // user defined list 2
-
-  for(i=0; i < DIC_SEARCH_REGE_LIST; i++)
-    {
-      memset(llist.letters[i],0,sizeof(llist.letters[i]));
-    }
-
-  const std::vector<Tile>& allTiles = dic->getAllTiles();
-  std::vector<Tile>::const_iterator it;
-  for (it = allTiles.begin(); it != allTiles.end(); it++)
-    {
-      if (! it->isJoker() && ! it->isEmpty())
-	{
-	  // all tiles
-	  llist.letters[0][it->toCode()] = 1;
-	  // vowels
-	  if (it->isVowel())
-	    {
-	      llist.letters[1][it->toCode()] = 1;
-	    }
-	  // consonants
-	  if (it->isConsonant())
-	    {
-	      llist.letters[2][it->toCode()] = 1;
-	    }
-	}
-    }
-}
-
 void
 PRegExp::panel_options()
 {
@@ -320,8 +268,6 @@ PRegExp::compute_enter(wxCommandEvent&)
     if (!check_dic())
         return;
 
-    build_letter_lists();
-
     wstring regexp = t->GetValue().wc_str();
     debug("PRegExp::compute_enter for %ls", regexp.c_str());
 
@@ -329,8 +275,6 @@ PRegExp::compute_enter(wxCommandEvent&)
     int lmax = atoi((const char*)omax->GetValue().mb_str());
     if (lmax <= (DIC_WORD_MAX - 1) && lmin >= 1 && lmin <= lmax)
     {
-        llist.minlength = lmin;
-        llist.maxlength = lmax;
         debug(" length %d,%d",lmin,lmax);
     }
     else
@@ -338,15 +282,25 @@ PRegExp::compute_enter(wxCommandEvent&)
         debug(" bad length -%s,%s-",
               (const char*)omin->GetValue().mb_str(),
               (const char*)omax->GetValue().mb_str());
+        return;
     }
     debug("\n");
 
-    list<wstring> wordList;
-    dic->searchRegExp(regexp, wordList, &llist);
+    vector<wstring> wordList;
+    try
+    {
+        dic->searchRegExp(regexp, wordList, lmin, lmax);
+    }
+    catch (InvalidRegexpException &e)
+    {
+        wxString msg = _("Invalid regular expression: ") + wxU(e.what());
+        l->Append(msg);
+        return;
+    }
 
     wxString *res = new wxString[wordList.size()];
     int resnum = 0;
-    list<wstring>::const_iterator it;
+    vector<wstring>::const_iterator it;
     for (it = wordList.begin(); it != wordList.end(); it++)
     {
         res[resnum++] =  wxU(it->c_str());
